import libfmp4

# A simple "global" context to save things prepared by "setup"
# and make them available in "update_manifest" calls. Also used
# to store mp4_process_context_t mainly for logging.

class ContextClass:

    def __init__(self):
        self._pipelines = None
        self._format = None
        self._mp4context = None
        # Default logging methods to be used only if an mp4 context is not
        #  available
        self.log_debug   = lambda msg: print('DEBUG: {}'.format(msg))
        self.log_warning = lambda msg: print('WARNING: {}'.format(msg))
        self.log_error   = lambda msg: print('ERROR: {}'.format(msg))

    def fmp4_log_debug(self, msg):
        return libfmp4.log_debug(self._mp4context, msg)

    def fmp4_log_warning(self, msg):
        return libfmp4.log_warning(self._mp4context, msg)

    def fmp4_log_error(self, msg):
        return libfmp4.log_error(self._mp4context, msg)

    @property
    def pipelines(self):
        return self._pipelines

    @pipelines.setter
    def pipelines(self, pipelines):
        self._pipelines = pipelines

    @property
    def format(self):
        return self._format

    @format.setter
    def format(self, format):
        self._format = format

    @property
    def mp4context(self):
        return self._mp4context

    @mp4context.setter
    def mp4context(self, mp4context):
        self._mp4context = mp4context
        #Replacing default logging function with those from fmp4
        self.log_debug = self.fmp4_log_debug
        self.log_warning = self.fmp4_log_warning
        self.log_error = self.fmp4_log_error

Context = ContextClass()