from manifest_edit import BasePlugin
from manifest_edit import Context

class Plugin(BasePlugin):
    '''An example plugin.
    It has 4 possible entry points, automatically invoked when a manifest
    of a given format is being processed, i.e.

    - if an .mpd manifest is being process, the "mdp" entrypoint will be called
    - if an .m3u8 manifest is being processed, the "m3u8" one will be
    - ... and so on

    All four entrypoints will receive as arguments:

    - manifest_in : the input manifest. This is always going to be a
      representation of the original input manifest, despite the position of
      this plugin in the processing pipeline.

    - manifest_out: the output manifest,
      with all the modifications already applied by all the plugins coming
      before this in the pipeline.

    The plugin's responsibility is to apply to manifest_out the
    desired modifications.

    It is essential to modify manifest_out in place and avoid to reassign
    manifest_out: this would not have the desired effect.

    In order to provide configuration parameters to this plugin, an user can
    specify them in the .yml configuraton file and they will be available to
    this plugin as a python dictionary in the special member

    - self.config

    '''
    # ----------------------------------------------------------
    # This is the only format supported for the moment
    def mpd(self, manifest):
        Context.log_debug('This is DASH process')
    # ----------------------------------------------------------
    
    # ----------------------------------------------------------
    # Other entrypoints will be used to implement
    def Manifest(self, manifest):
        Context.log_debug('HSS processing not implemented')

    def f4m(self, manifest):
        Context.log_debug('HDS processing not implemented')
    
    def m3u8(self, manifest):
        Context.log_debug('HLS processing not implemented')
    # ----------------------------------------------------------
